import { dataSource } from "../../data-source";
import { force } from "../../entity/configuration/force";
import DatabaseActionException from "../../exceptions/databaseActionException";

export default abstract class ForceService {
  /**
   * @description get all forces
   * @returns {Promise<[Array<force>, number]>}
   */
  static async getAll({
    offset = 0,
    count = 25,
    search = "",
    noLimit = false,
    ids = [],
  }: {
    offset?: number;
    count?: number;
    search?: string;
    noLimit?: boolean;
    ids?: Array<string>;
  }): Promise<[Array<force>, number]> {
    let query = dataSource.getRepository(force).createQueryBuilder("force");

    if (search != "") {
      search.split(" ").forEach((term, index) => {
        const searchQuery = `%${term}%`;
        const dynamic = "searchQuery" + Math.random().toString(36).substring(2);
        if (index == 0) {
          query = query.where(`force.firstname LIKE :${dynamic} OR force.lastname LIKE :${dynamic}`, {
            [dynamic]: searchQuery,
          });
        } else {
          query = query.orWhere(`force.firstname LIKE :${dynamic} OR force.lastname LIKE :${dynamic}`, {
            [dynamic]: searchQuery,
          });
        }
      });
    }

    if (ids.length != 0) {
      query = query.where("force.id IN (:...ids)", { ids: ids });
    }

    if (!noLimit) {
      query = query.offset(offset).limit(count);
    }

    return await query
      .orderBy("force.lastname")
      .addOrderBy("force.firstname")
      .addOrderBy("force.nameaffix")
      .getManyAndCount()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "force", err);
      });
  }

  /**
   * @description get force by id
   * @param {string} id
   * @returns {Promise<force>}
   */
  static async getById(id: string): Promise<force> {
    return dataSource
      .getRepository(force)
      .createQueryBuilder("force")
      .where("force.id = :id", { id: id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "force", err);
      });
  }
}
